defProperty('rxnode', 'node1-1.grid.orbit-lab.org', "Receive node")
defProperty('txnode', 'node20-20.grid.orbit-lab.org', "Transmit node")
defProperty('rate', '1.25M', "Bitrate")
defProperty('modulation','bpsk',"Modulation")
defProperty('freq', '1900000000', "Center frequency")
defProperty('runtime', 100, "Run time (s)")

defApplication('test:app:benchmark_rx3', 'benchmark_rx3.py') { |a|
  a.version(2, 0, 4)
  a.shortDescription = ""
  a.description = ""
  a.path = "export LC_ALL=C;/root/gnuradio/gr-digital/examples/narrowband/benchmark_rx3.py"
  a.defProperty('args', "Argument list", nil,
                {:dynamic => false, :type => :string})
  a.defProperty('freq', "center frequency in Hz", '-f',
                {:dynamic => false, :type => :string})
  a.defProperty('rx-gain', "receive gain in dB", '--rx-gain', 
                {:dynamic => false, :type => :string})
  a.defProperty('bitrate', "specify bitrate", '-r',
                {:dynamic => false, :type => :string})
  a.defProperty('modulation', "modulation: psk, cpm, qpsk, dqpsk, gfsk,qam, dbpsk, bpsk, gmsk [default=psk]", '-m', 
                {:dynamic => false, :type => :string})
  a.defProperty('constellation-points', "set constellation - power of two for psk, power of 4 for QAM [default=16]", '-p', 
                {:dynamic => false, :type => :string})
}

defApplication('test:app:benchmark_tx3', 'benchmark_tx3.py') { |a|
  a.version(2, 0, 4)
  a.shortDescription = ""
  a.description = ""
  a.path = "export LC_ALL=C;/root/gnuradio/gr-digital/examples/narrowband/benchmark_tx3.py"
  a.defProperty('args', "Argument list", nil,
                {:dynamic => false, :type => :string})
  a.defProperty('freq', "center frequency in Hz", '-f',
                {:dynamic => false, :type => :string})
  a.defProperty('tx-gain', "transmit gain in dB", '--tx-gain', 
                {:dynamic => false, :type => :string})
  a.defProperty('tx-amplitude', "transmitter digital amplitude [0,1)  [default=0.25", '--tx-amplitude', 
                {:dynamic => false, :type => :string})
  a.defProperty('bitrate', "specify bitrate", '-r',
                {:dynamic => false, :type => :string})
  a.defProperty('modulation', "modulation: psk, cpm, qpsk, dqpsk, gfsk,qam, dbpsk, bpsk, gmsk [default=psk]", '-m', 
                {:dynamic => false, :type => :string})
  a.defProperty('constellation-points', "set constellation - power of two for psk, power of 4 for QAM [default=16]", '-p',
                {:dynamic => false, :type => :string})
}

defGroup('rx_node', property.rxnode) { |n|
 n.addApplication('test:app:benchmark_rx3') { |app|
   app.setProperty('freq', property.freq)
   app.setProperty('modulation',property.modulation)
   app.setProperty('bitrate',property.rate)
   app.setProperty('rx-gain','30')
 }
}

defGroup('tx_node', property.txnode) { |n|
 n.addApplication('test:app:benchmark_tx3') { |app|
   app.setProperty('freq', property.freq)
   app.setProperty('modulation',property.modulation)
   app.setProperty('bitrate',property.rate)
   app.setProperty('tx-gain','30')
   app.setProperty('tx-amplitude','0.5')
 }
}

onEvent(:ALL_UP_AND_INSTALLED) { |event|
  info "Give machines some time to warm up :-)" 
  wait 2
  info "Starting the packet server"
  consoleExec("/usr/local/bin/pkt_server --oml-exp-id #{Experiment.ID} --duration #{property.runtime} &")
  info "Configuring interference"
  consoleHttp("http://instrument1.orbit-lab.org:5054/interference/initialize")
  consoleHttp("http://instrument1.orbit-lab.org:5054/interference/set?frequency=#{property.freq}&power=-40")
  consoleHttp("http://instrument1.orbit-lab.org:5054/interference/train?bandwidth=2.5&duration=#{property.runtime}")
  info "Starting interference"
  consoleHttp("http://instrument1.orbit-lab.org:5054/interference/start")
  info "Starting benchmark_rx"
  group("rx_node").startApplications
  info "Starting benchmark_tx"
  group("tx_node").startApplications
  info "Runing for #{property.runtime} seconds..."
  wait property.runtime
  info "Done! Stop eveything"
  allGroups.stopApplications
  consoleHttp("http://instrument1.orbit-lab.org:5054/interference/stop")
  wait 5
  consoleExec("pkill pkt_server")
  Experiment.done
}
